@@ -49,7 +49,7 @@ def ensure_clean_working_tree() -> None:
 
 def get_head() -> Commit:
     """Get the head commit with its parent(s)"""
-    cmd = ["git", "log", "--pretty='%h %p'", "-n", "1"]
+    cmd = ["git", "log", "--pretty=%h %p", "-n", "1"]
     result = run(cmd, stdout=PIPE)
     shas = result.stdout.decode().strip().split(" ")
     return Commit(*shas)
@@ -59,7 +59,7 @@ def get_repo_name() -> str:
     cmd = ["git", "remote", "get-url", "origin"]
     result = run(cmd, stdout=PIPE)
     url = result.stdout.decode().strip()
-    name = url.split("/")[-1].split(".")[0]
+    name = url.split("/")[-1].split(".")[0].replace("github_aaa-ncnu_", "")
     return name
 
 
